# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-02-17 13:22
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0011_auto_20170217_1120'),
    ]

    operations = [
        migrations.AlterField(
            model_name='incident',
            name='service',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='incidents', related_query_name='incident', to='statusboard.Service', verbose_name='service'),
        ),
    ]
