{% extends "statusboard/base.html" %}

{% load statusboard %}
{% load i18n %}

{% block content %}
<div class="container">
    <h1>{% trans "Delete a service group" %}</h1>
    <form class="form-horizontal" role="form" method="post" action="">
        {% csrf_token %}
        <p>{% blocktrans %}Are you sure you want to delete the service group "{{ servicegroup }}"? {% endblocktrans %}</p>
        <div class="form-group">
            <input type="submit" class="btn btn-primary" value="{% trans "Confirm" %}">
            <a class="btn btn-secondary" role="button" href="{% url "statusboard:index" %}">{% trans "Cancel" %}</a>
        </div>
    </form>
</div>
{% endblock %}

