# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-23 15:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0018_merge_20170223_1429'),
    ]

    operations = [
        migrations.AlterField(
            model_name='service',
            name='priority',
            field=models.PositiveIntegerField(default=0, verbose_name='priority'),
        ),
        migrations.AlterField(
            model_name='servicegroup',
            name='priority',
            field=models.PositiveIntegerField(default=0, verbose_name='priority'),
        ),
    ]
