{% extends "statusboard/base.html" %}

{% load humanize %}
{% load statusboard %}
{% load i18n %}

{% block content %}
<div class="container">
    <h2>{% trans "No incidents found" %}</h2>
</div>
{% endblock %}
