# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-01-25 06:11
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0003_auto_20170125_0604'),
    ]

    operations = [
        migrations.AddField(
            model_name='incident',
            name='occurred',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
