{% load i18n %}

<div class="alert alert-info " role="alert">
    <i class="bi bi-exclamation-triangle"></i>
    {% blocktrans %}
    Mantaineance messages are meant as an alert before an event and the home
    page will show the maintenance message until the scheduled time expires.
    Any information regarding the maintenance should be filed as an incident.
    {% endblocktrans %}
</div>
