# Generated by Django 3.0.10 on 2020-12-04 08:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0020_auto_20170223_1651'),
    ]

    operations = [
        migrations.AlterField(
            model_name='service',
            name='groups',
            field=models.ManyToManyField(blank=True, related_name='services', related_query_name='service', to='statusboard.ServiceGroup', verbose_name='groups'),
        ),
    ]
