# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-23 14:29
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0016_auto_20170223_1005'),
        ('statusboard', '0017_auto_20170223_1428'),
    ]

    operations = [
    ]
