# Generated by Django 3.0.10 on 2020-12-04 08:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0021_auto_20201204_0846'),
    ]

    operations = [
        migrations.AlterField(
            model_name='maintenance',
            name='scheduled',
            field=models.DateTimeField(verbose_name='scheduled start'),
        ),
    ]
