# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-23 16:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0019_auto_20170223_1503'),
    ]

    operations = [
        migrations.AlterField(
            model_name='service',
            name='description',
            field=models.TextField(blank=True, verbose_name='description'),
        ),
    ]
