# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-22 19:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0013_auto_20170220_1444'),
    ]

    operations = [
        migrations.AddField(
            model_name='incident',
            name='closed',
            field=models.BooleanField(default=False),
        ),
    ]
