# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-23 14:28
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0016_service_position'),
    ]

    operations = [
        migrations.RenameField(
            model_name='service',
            old_name='position',
            new_name='priority',
        ),
        migrations.RenameField(
            model_name='servicegroup',
            old_name='position',
            new_name='priority',
        ),
    ]
