# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-02-17 11:20
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0010_auto_20170217_0835'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='incident',
            options={'verbose_name': 'incident', 'verbose_name_plural': 'incidents'},
        ),
        migrations.AlterModelOptions(
            name='incidentupdate',
            options={'verbose_name': 'incident update', 'verbose_name_plural': 'incident updates'},
        ),
        migrations.AlterModelOptions(
            name='maintenance',
            options={'verbose_name': 'maintenance', 'verbose_name_plural': 'maintenances'},
        ),
        migrations.AlterModelOptions(
            name='service',
            options={'verbose_name': 'service', 'verbose_name_plural': 'services'},
        ),
        migrations.AlterModelOptions(
            name='servicegroup',
            options={'verbose_name': 'service group', 'verbose_name_plural': 'service groups'},
        ),
        migrations.AlterField(
            model_name='incident',
            name='name',
            field=models.CharField(max_length=255, verbose_name='name'),
        ),
        migrations.AlterField(
            model_name='incident',
            name='occurred',
            field=models.DateTimeField(default=django.utils.timezone.now, verbose_name='occurred'),
        ),
        migrations.AlterField(
            model_name='incident',
            name='service',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='statusboard.Service', verbose_name='service'),
        ),
        migrations.AlterField(
            model_name='incidentupdate',
            name='description',
            field=models.TextField(verbose_name='description'),
        ),
        migrations.AlterField(
            model_name='incidentupdate',
            name='incident',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='updates', related_query_name='update', to='statusboard.Incident', verbose_name='incident'),
        ),
        migrations.AlterField(
            model_name='incidentupdate',
            name='status',
            field=models.IntegerField(choices=[(0, 'Investigating'), (1, 'Identified'), (2, 'Watching'), (3, 'Fixed')], verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='maintenance',
            name='description',
            field=models.TextField(verbose_name='description'),
        ),
        migrations.AlterField(
            model_name='maintenance',
            name='name',
            field=models.CharField(max_length=255, verbose_name='name'),
        ),
        migrations.AlterField(
            model_name='maintenance',
            name='scheduled',
            field=models.DateTimeField(verbose_name='scheduled'),
        ),
        migrations.AlterField(
            model_name='service',
            name='description',
            field=models.TextField(verbose_name='description'),
        ),
        migrations.AlterField(
            model_name='service',
            name='groups',
            field=models.ManyToManyField(related_name='services', related_query_name='service', to='statusboard.ServiceGroup', verbose_name='groups'),
        ),
        migrations.AlterField(
            model_name='service',
            name='name',
            field=models.CharField(max_length=255, unique=True, verbose_name='name'),
        ),
        migrations.AlterField(
            model_name='service',
            name='status',
            field=models.IntegerField(choices=[(0, 'Operational'), (1, 'Performance issues'), (2, 'Partial outage'), (3, 'Major outage')], verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='servicegroup',
            name='collapse',
            field=models.IntegerField(choices=[(0, 'Never collapse'), (1, 'Always collapse'), (2, 'Collapse when a service is not operational')], default=0),
        ),
        migrations.AlterField(
            model_name='servicegroup',
            name='name',
            field=models.CharField(max_length=255, unique=True, verbose_name='name'),
        ),
    ]
