# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-02-17 07:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0008_servicegroup_collapse'),
    ]

    operations = [
        migrations.AlterField(
            model_name='servicegroup',
            name='collapse',
            field=models.IntegerField(choices=[(0, 'Never collapse'), (1, 'Always collapse'), (2, 'When service is not operational')], default=0),
        ),
    ]
