# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-22 20:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0013_auto_20170220_1444'),
        ('statusboard', '0009_servicegroup_position'),
    ]

    operations = [
    ]
